* { margin: 0; padding: 0; color: #333; font-family: Optima }
* body { background: #ddf; font-size: 12pt; }
li { margin-left: 2em; }
p { margin: 1em 0; }
input { border: 1px solid #99f; font-size: 1.1em; }
textarea { font-size: 1.1em; border: 1px solid #99f; }
table th { text-align: left }
button { margin: 0.5em; }

table { border: 1px solid #99f; border-collapse: collapse }

th { vertical-align: bottom; padding: 3px; border: 1px solid #aaaaff; background: #aaaaff url(lib/jquery/images/ui-bg_glass_65_aaaaff_1x400.png) 50% 50% repeat-x; font-weight: normal; color: #212155; }
td { vertical-align: top; padding: 3px }

blockquote, pre { margin: 1em 1em; padding: 1em; border: 1px solid #ddf; background-color: #eef; }

#masthead { padding: 2em 1em; background: #ddf; }
#masthead .main-title { color: #339; }
#navigation .navigation, #bottom-navigation .navigation { margin: 0 3px; list-style: none; float: left }

#bottom-navigation { padding: 2em 1em; background: #ddf; }

#main { padding: 1em; background: #fff; }
#main h1, #main h2, #main h3 { margin: 0.5em 0; border-bottom: 1px solid #ccf; color: #225; }
#breadcrumb li { list-style: none; display: inline-block; margin: 0; }

div.field { margin: 1em; }
div.field label { display: inline-block; width: 10em; text-align: right }

div.button-group { text-align: right }
div.progress { height: 15px }

.links li { display: inline-block; margin: 0 3px; list-style: none }

/*** Login ***/

#login-page { width: 30em; margin: 8em auto }

/*** Page ***/

a.not-exists { color: #800; }
a.footnote { color: #33f; font-size: 0.5em; vertical-align: super }
a.footnote:before { content: '[' }
a.footnote:after { content: ']' }

textarea#yukkitext { width: 100%; height: 20em; }
input#comment { width: 100%; }

.pane { width: 48% }
div#preview-yukkitext { border: 1px solid #99f; padding: 5px; height: 28em; overflow: auto; float: right; }

/*** File Upload ***/

div.attachments { border: 1px solid #ddf; margin-top: 0.5em; padding: 3px }
div.attachments .attachment-list.empty { text-align: center }
table.attachment-table { width: 100% }
table.attachment-table .filename { width: 65% }
table.attachment-table .size { width: 10% }
table.attachment-table .action { width: 25% }
div.attachment-dropzone { background: #eef; text-align: center; padding: 1em; margin: 0.5em 0 }
